@@ -165,6 +165,7 @@ static void create_window(void)
 	label = gtk_label_new(NULL);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	text = g_markup_printf_escaped("<span size=\"larger\"><b>%s</b></span>",
+	/* translators: This is the heading for the progress dialogue */
 					_("Sending files via Bluetooth"));
 	gtk_label_set_markup(GTK_LABEL(label), text);
 	g_free(text);
@@ -239,7 +240,7 @@ static gchar *get_error_message(GError *error)
 	const gchar *name;
 
 	if (error == NULL)
-		return g_strdup(_("An unknown error occured"));
+		return g_strdup(_("An unknown error occurred"));
 
 	if (error->code != DBUS_GERROR_REMOTE_EXCEPTION) {
 		message = g_strdup(error->message);
